@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Number::Tolerant;
 # ABSTRACT: tolerance ranges for inexact numbers
-$Number::Tolerant::VERSION = '1.706';
+$Number::Tolerant::VERSION = '1.707';
 use Sub::Exporter::Util;
 use Sub::Exporter 0.950 -setup => {
   exports => { tolerance => Sub::Exporter::Util::curry_class('new'), },
@@ -296,7 +296,7 @@ sub intersection {
   if (defined $_[0]->{min} and defined $_[1]->{min}) {
     ($min) = sort {$b<=>$a}  ($_[0]->{min}, $_[1]->{min});
   } else {
-    $min = $_[0]->{min} || $_[1]->{min};
+    $min = defined $_[0]->{min} ? $_[0]->{min} : $_[1]->{min};
   }
 
   $exclude_min = 1
@@ -306,7 +306,7 @@ sub intersection {
   if (defined $_[0]->{max} and defined $_[1]->{max}) {
     ($max) = sort {$a<=>$b} ($_[0]->{max}, $_[1]->{max});
   } else {
-    $max = $_[0]->{max} || $_[1]->{max};
+    $max = defined $_[0]->{max} ? $_[0]->{max} : $_[1]->{max};
   }
 
   $exclude_max = 1
@@ -525,7 +525,7 @@ Number::Tolerant - tolerance ranges for inexact numbers
 
 =head1 VERSION
 
-version 1.706
+version 1.707
 
 =head1 SYNOPSIS
 
@@ -797,7 +797,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexandre Mestiashvili Karen Etheridge Ricardo SIGNES Smylers
+=for stopwords Alexandre Mestiashvili Karen Etheridge Michael Carman Ricardo SIGNES Smylers
 
 =over 4
 
@@ -811,6 +811,10 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
+Michael Carman <mjcarman@cpan.org>
+
+=item *
+
 Ricardo SIGNES <rjbs@codesimply.com>
 
 =item *
